@@ -1,25 +1,11 @@
-# Copyright (c) 2000-2004 Dave Rolsky
-# All rights reserved.
-# This program is free software; you can redistribute it and/or
-# modify it under the same terms as Perl itself.  See the LICENSE
-# file that comes with this distribution for more details.
 package Params::Validate;
 
 use strict;
+use warnings;
 
-require DynaLoader;
+require XSLoader;
+XSLoader::load( 'Params::Validate', $Params::Validate::VERSION );
 
-if ( $] >= 5.006 )
-{
-    require XSLoader;
-    XSLoader::load( 'Params::Validate', $Params::Validate::VERSION );
-}
-else
-{
-    require DynaLoader;
-    push @ISA, 'DynaLoader';
-    Params::Validate->bootstrap( $Params::Validate::VERSION );
-}
 
 my $default_fail = sub { require Carp;
                          Carp::confess($_[0]) };
@@ -167,8 +153,8 @@ Params::Validate documentation for details.
 
 =head1 COPYRIGHT
 
-Copyright (c) 2004 David Rolsky.  All rights reserved.  This program
-is free software; you can redistribute it and/or modify it under the
-same terms as Perl itself.
+Copyright (c) 2004-2007 David Rolsky.  All rights reserved.  This
+program is free software; you can redistribute it and/or modify it
+under the same terms as Perl itself.
 
 =cut
